@@ -1,12 +1,20 @@
 from tools_hjh.DBConn import DBConn
+from tools_hjh.DBConn import oracletools
+from tools_hjh.DBConn import MemoryDB
+
 from tools_hjh.SSHConn import SSHConn
+
 from tools_hjh.ThreadPool import ThreadPool
 
+from tools_hjh.HttpRequest import HttpRequest
+from tools_hjh.HttpRequest import httptools
+
 from tools_hjh.other import Log
 
 from tools_hjh.other import locattime
 from tools_hjh.other import locatdate
 from tools_hjh.other import cat
+from tools_hjh.other import sql_remove_comments
 from tools_hjh.other import echo
 from tools_hjh.other import mkdir
 from tools_hjh.other import rm
@@ -14,4 +22,4 @@ from tools_hjh.other import spacesmerge
 from tools_hjh.other import nvl
 from tools_hjh.other import round_
 from tools_hjh.other import timeformat
-from tools_hjh.other import zipfolder
\ No newline at end of file
+from tools_hjh.other import zipfolder
